**Example 1: 删除规则模版**

删除规则模版

Input: 

```
tccli wedata DeleteRuleTemplate --cli-unfold-argument  \
    --ProjectId 1 \
    --Ids 1
```

Output: 
```
{
    "Response": {
        "Data": true,
        "RequestId": "xx"
    }
}
```

